<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>KeePassXC 정보</translation>
    </message>
    <message>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>기여자</translation>
    </message>
    <message>
        <source>Debug Info</source>
        <translation>디버그 정보</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>클립보드에 복사</translation>
    </message>
    <message>
        <source>Version %1
</source>
        <translation>버전 %1
</translation>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation>리비전: %1</translation>
    </message>
    <message>
        <source>Libraries:</source>
        <translation>라이브러리:</translation>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation>운영 체제: %1
CPU 아키텍처: %2
커널: %3 %4</translation>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation>활성화된 확장 기능:</translation>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation> &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt; 사이트에 버그를 보고해 주십시오</translation>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC는 GNU 일반 공중 라이선스(GPL) 버전 2 및 (선택적으로) 버전 3으로 배포됩니다.</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation>프로젝트 관리자:</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;GitHub에서 기여자 보기&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation>버그를 보고할 때 다음 정보를 포함하십시오:</translation>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation>배포판: %1</translation>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>이 선택 기억하기</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>허용</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>거부</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1에서 다음 항목의 암호를 요청했습니다.
접근을 허용할 지 여부를 선택하십시오.</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>KeePassXC HTTP 접근 확인</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>창 제목과 일치하는 항목을 찾을 수 없습니다:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>자동 입력 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>시퀀스</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>기본 시퀀스</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>자동으로 입력할 항목 선택:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>자동 입력 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>암호 입력:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>암호 확인:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>만들기</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>키 파일 만들기...</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>키 파일을 만들 수 없습니다: </translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>키 파일 선택</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>빈 문자열을 암호로 사용하시겠습니까?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>다른 암호를 입력하였습니다.</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>%1을(를) 키 파일로 설정할 수 없습니다: %2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>키 파일(&amp;K)</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation>질의 응답(&amp;L)</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Empty password</source>
        <translation>빈 암호</translation>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation>마스터 키를 변경할 수 없음: YubiKey가 없습니다.</translation>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation>복제 옵션</translation>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation>사용자 이름과 암호를 참조로 대체</translation>
    </message>
    <message>
        <source>Copy history</source>
        <translation>과거 기록 복사</translation>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation>제목에 &apos; - 사본&apos; 추가</translation>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation>CSV 필드 가져오기</translation>
    </message>
    <message>
        <source>filename</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation>크기, 줄, 칸</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>인코딩</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>인코딩</translation>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation>문자열 구분자</translation>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation>필드 구분자</translation>
    </message>
    <message>
        <source>Comments start with</source>
        <translation>주석 시작 글자</translation>
    </message>
    <message>
        <source>First record has field names</source>
        <translation>첫 레코드에 필드 이름 포함</translation>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation>무시할 머릿글 줄 수</translation>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation>&apos;\&apos; 글자를 탈출 문자로 간주</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>미리 보기</translation>
    </message>
    <message>
        <source>Column layout</source>
        <translation>칸 레이아웃</translation>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation>CSV 파일에 없음</translation>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation>빈 필드 이름 </translation>
    </message>
    <message>
        <source>column </source>
        <translation>칸 </translation>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation>CSV 파일에서 가져옴</translation>
    </message>
    <message>
        <source>Original data: </source>
        <translation>원본 데이터:</translation>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation>CSV 파일에 오류가 있습니다!</translation>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation>개 메시지 더 건너뜀]</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation>CSV 가져오기: 기록 중 오류 발생:
</translation>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation>CSV 파일 가져오기</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation>바이트, </translation>
    </message>
    <message>
        <source> rows, </source>
        <translation>줄, </translation>
    </message>
    <message>
        <source> columns</source>
        <translation>칸</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>마스터 키 입력</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>키 파일:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>키 파일을 열 수 없음</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>키 파일</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>키 파일 선택</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation>질의 응답:</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>데이터베이스 복구</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>키 파일을 열 수 없음</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>데이터베이스를 열었습니다. 할 일이 없습니다.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>성공</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>데이터베이스를 복구했습니다
이제 저장할 수 있습니다.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>데이터베이스를 복구할 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>데이터베이스 이름:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>데이터베이스 설명:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>변환 횟수:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>기본 사용자 이름:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>벤치마크</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>최대 과거 항목 수:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>최대 과거 항목 크기:</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>휴지통 사용</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation>AES: 256비트(기본값)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish: 256비트</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>알고리즘:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>루트</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 데이터베이스</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>데이터베이스 열기</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>파일을 찾을 수 없습니다!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>KeePass 1 데이터베이스 열기</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 데이터베이스</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>모든 파일 (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>닫기 확인?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>변경 사항 저장 확인?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot;이(가) 변경되었습니다. 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>데이터베이스에 쓸 수 없습니다.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>다른 이름으로 데이터베이스 저장</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>새 데이터베이스</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>잠김</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>데이터베이스를 편집하고 있어서 잠글 수 없습니다.
취소를 눌러서 변경 사항을 저장하거나 무시하십시오.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>이 데이터베이스가 저장되지 않았습니다.
데이터베이스를 저장하거나 잠금을 풀 수 있습니다.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>데이터베이스가 수정되었습니다.
잠그기 전에 데이터베이스를 저장하시겠습니까?
저장하지 않은 변경 사항은 손실됩니다.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot;이(가) 현재 편집 모드입니다.
변경 사항을 무시하고 닫으시겠습니까?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>데이터베이스를 CSV 파일로 내보내기</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV 파일</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>CSV 파일에 기록할 수 없습니다.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>데이터베이스 합치기</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>저장하려는 데이터베이스를 다른 KeePassXC 인스턴스에서 잠갔습니다.
그래도 저장하시겠습니까?</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>데이터베이스가 이미 열림</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>열려는 데이터베이스를 다른 KeePassXC 인스턴스에서 잠갔습니다.

그래도 여시겠습니까?</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>읽기 전용으로 열기</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation>파일을 읽기 전용 모드로 열었습니다.</translation>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation>CSV 파일 열기</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>마스터 키 변경</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>항목을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>정말 항목 &quot;%1&quot;을(를) 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>항목을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>정말 항목 %1개를 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>항목을 휴지통으로 이동하시겠습니까?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>항목 %n개를 휴지통으로 이동하시겠습니까?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>그룹을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>정말 그룹 &quot;%1&quot;을(를) 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없음</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>항목을 휴지통으로 이동하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>항목 &quot;%1&quot;을(를) 휴지통으로 이동하시겠습니까?</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>찾는 중...</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>현재 데이터베이스가 없습니다.</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>원본 데이터베이스가 없습니다.</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>검색 결과(%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>결과 없음</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>명령을 실행하시겠습니까?</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>다음 명령을 실행하시겠습니까?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>이 선택 기억하기</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>요청 자동으로 새로 고침</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>데이터베이스 파일이 변경되었습니다. 변경 사항을 불러오시겠습니까?</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>요청 합치기</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>데이터베이스 파일이 변경되었고 저장하지 않은 변경 사항이 있습니다. 변경 사항을 합치겠습니까?</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>이 데이터베이스를 자동으로 다시 불러오는 중 새 데이터베이스를 열 수 없습니다.</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation>휴지통을 비우시겠습니까?</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation>휴지통에 있는 항목을 영원히 삭제하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>항목</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>고급</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>아이콘</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>자동 입력</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <source>History</source>
        <translation>과거 기록</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>항목 과거 기록</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>항목 추가</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>항목 편집</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>다른 암호를 입력하였습니다.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>새 속성</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>파일 선택</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>파일을 열 수 없습니다</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>첨부 항목 저장</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>첨부 항목을 저장할 수 없습니다:</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>내일</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n주</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n개월</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1년</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation>삭제 확인</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation>이 속성을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation>[보호됨] 보거나 편집하려면 누르십시오</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation>이 첨부 항목을 삭제하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>추가 속성</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>첨부</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>이름 편집</translation>
    </message>
    <message>
        <source>Protect</source>
        <translation>보호</translation>
    </message>
    <message>
        <source>Reveal</source>
        <translation>보이기</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>이 항목 자동 입력 사용</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>창 제목:</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>그룹의 기본 자동 입력 시퀀스 사용(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>사용자 정의 자동 입력 시퀀스 사용(&amp;U):</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>기본 시퀀스 사용(&amp;Q)</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>사용자 정의 시퀀스 설정(&amp;M):</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation>창 연결</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>보이기</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>복원</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>모두 삭제</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>제목:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자 이름:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>암호 확인:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>만료 기간</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>사전 설정</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>메모:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>아이콘</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>속성</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>그룹 추가</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>그룹 편집</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>활성화</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>비활성화</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>부모 그룹에서 상속(%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>만료 기간</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>자동 입력</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation>그룹의 기본 자동 입력 시퀀스 사용(&amp;G)</translation>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation>기본 자동 입력 시퀀스 설정(&amp;Q)</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>사용자 정의 아이콘 추가</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>사용자 정의 아이콘 삭제</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>그림</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>그림 선택</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>파비콘 다운로드</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>파비콘을 다운로드할 수 없습니다.</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>아이콘을 읽을 수 없음</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>기본 아이콘 사용(&amp;U)</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>사용자 정의 아이콘 사용(&amp;M)</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation>삭제 확인</translation>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation>이 아이콘을 항목 %1개에서 사용하고 있으며, 삭제 시 기본 아이콘으로 대체됩니다. 그래도 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation>힌트: 도구 &gt; 설정 &gt; 보안에서 Google을 대체 항목으로 사용할 수 있습니다</translation>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation>사용자 정의 아이콘이 이미 존재함</translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>만든 날짜:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>수정한 날짜:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>접근한 날짜:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>UUID:</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation> - 사본</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>마지막 수정</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation>참조: </translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>휴지통</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>길이:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>문자 종류</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>대문자</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>소문자</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>숫자</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>특수 문자</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>비슷하게 생긴 문자 제외</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>모든 그룹에서 최소 1글자 이상 포함</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation>닫기(&amp;C)</translation>
    </message>
    <message>
        <source>Close message</source>
        <translation>메시지 닫기</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>KeePass1 데이터베이스 가져오기</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>데이터베이스를 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>키 파일을 읽을 수 없습니다.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass 데이터베이스가 아닙니다.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>지원하지 않는 암호화 알고리즘입니다.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>지원하지 않는 KeePass 데이터베이스 버전입니다.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>루트</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없음</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>키가 잘못되었거나 데이터베이스가 손상되었습니다.</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass 데이터베이스가 아닙니다.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>지원하지 않는 KeePass 데이터베이스 버전입니다.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>키가 잘못되었거나 데이터베이스가 손상되었습니다.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없습니다</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>질의 응답을 실행할 수 없습니다.</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>선택한 파일은 KeePass 1 데이터베이스(.kdb)입니다.

데이터베이스 &gt; &apos;KeePass 1 데이터베이스 가져오기...&apos; 메뉴에서 항목을 가져올 수 있습니다.
이 작업은 한 방향으로만 이뤄집니다. 가져온 데이터베이스는 KeePassX 0.4 버전에서 열 수 없습니다.</translation>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>질의 응답을 실행할 수 없습니다.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>마스터 키를 계산할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>암호화 함수를 시험하는 중 오류가 발생하였습니다.</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>KeePassXC - 오류</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation>잠금 파일을 만들 수 없습니다. 단일 인스턴스 모드가 비활성화되었습니다.</translation>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation>다른 KeePassXC 인스턴스가 이미 실행 중입니다.</translation>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation>존재하는 단일 인스턴스 잠금 파일이 잘못되었습니다. 새 인스턴스를 실행합니다.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>데이터베이스 열기</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>데이터베이스 설정</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>클립보드에 사용자 이름 복사</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>클립보드에 암호 복사</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>도구 모음 보이기</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>읽기 전용</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>창 전환</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 데이터베이스</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>모든 파일</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>복구한 데이터베이스 저장</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>데이터베이스에 쓸 수 없습니다.</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>최근 데이터베이스(&amp;R)</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>항목(&amp;N)</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>속성을 클립보드에 복사(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>그룹(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>보기(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>끝내기(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>정보(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>데이터베이스 저장(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>데이터베이스 닫기(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>새 데이터베이스(&amp;N)</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>KeePassX 데이터베이스에서 합치기</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>새 항목 추가(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>항목 보기/편집(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>항목 삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>새 그룹 추가(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>그룹 편집(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>그룹 삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>데이터베이스 설정(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>항목 복제(&amp;C)</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation>시간 동기 일회용 암호</translation>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation>TOTP 복사(&amp;T)</translation>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation>TOTP 보이기</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>찾기(&amp;F)</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>사용자 이름 복사(&amp;U)</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>암호 복사(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>설정(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>자동 입력 실행(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>URL 열기(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>데이터베이스 잠금(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>제목(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>URL(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>메모(&amp;N)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>암호 생성기</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>과거 기록 삭제</translation>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation>데이터베이스(&amp;D)</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>도구(&amp;T)</translation>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation>휴지통 비우기</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>설정 파일 %1에 접근할 수 없음</translation>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation>KeePassXC 끝내기</translation>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation>YubiKey의 단추를 누르십시오!</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>도움말(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation>데이터베이스 열기(&amp;O)...</translation>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation>다른 이름으로 데이터베이스 저장(&amp;V)...</translation>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation>마스터 키 변경(&amp;M)...</translation>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation>CSV 파일로 내보내기(&amp;E)...</translation>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation>KeePass1 데이터베이스 가져오기...</translation>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation>CSV 파일 가져오기...</translation>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation>데이터베이스 복구(&amp;P)...</translation>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation>TOTP 설정...</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>대화 상자</translation>
    </message>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>인증 정보가 필요할 때 알림 표시(&amp;O)</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>사용자 이름 순으로 일치하는 항목 정렬(&amp;U)</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>활성 데이터베이스에 있는 항목에서 모든 저장된 권한 삭제(&amp;M)</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>고급</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>항상 항목 접근 허용(&amp;A)</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>항상 항목 업데이트 허용(&amp;U)</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>모든 열린 데이터베이스에서 일치하는 항목 검색(&amp;H)</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP 포트:</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>기본 포트: 19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>데이터베이스가 잠겼을 때 잠금 해제 요청(&amp;Q)</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>제목 순으로 일치하는 항목 정렬(&amp;M)</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeePassXC는 127.0.0.1의 다음 포트에서 응답을 기다립니다</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>권한 있는 포트에 바인드할 수 없음</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>1024 이하의 권한이 필요한 포트에 바인드할 수 없습니다!
기본 포트 19455를 사용합니다.</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>활성 데이터베이스에 있는 모든 공유된 암호화 키 삭제(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>&quot;KPH: &quot;로 시작하는 고급 문자열 필드 반환(&amp;R)</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>문자열 필드를 자동으로 만들거나 업데이트하는 것은 지원되지 않습니다.</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation>ChromeIPass나 PassIFox에서 데이터베이스에 접근하려면 필요합니다</translation>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation>KeePassHTTP 서버 사용</translation>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation>도메인이 일치하는 모든 항목 대신 지정한 URL과 일치하는 항목만 반환합니다.</translation>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation>URL과 일치하는 항목만 반환(&amp;R)</translation>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation>같은 스키마(http://, https://, ftp://)를 사용하는 항목만 반환합니다.</translation>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation>URL 스키마 일치(&amp;M)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>암호 생성기</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation>선택한 데이터베이스만 클라이언트와 연결할 수 있습니다.</translation>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation>다음 옵션은 위험할 수도 있습니다!
무엇을 하는 지 알고 있는 경우에만 변경하십시오.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>암호:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>문자 종류</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>대문자</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>소문자</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>숫자</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>특수 문자</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>비슷하게 생긴 문자 제외</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>사용</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>강도</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>엔트로피</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>길이(&amp;L):</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>모든 그룹에서 글자 선택</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>생성</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation>엔트로피: %1비트</translation>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>암호 강도: %1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>매우 약함</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>약함</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>좋음</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>매우 좋음</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation>확장 ASCII</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>암구호</translation>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation>단어 목록:</translation>
    </message>
    <message>
        <source>Word Count:</source>
        <translation>단어 개수:</translation>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation>단어 구분자:</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation>NULL 장치</translation>
    </message>
    <message>
        <source>error reading from device</source>
        <translation>장치에서 읽는 중 오류 발생</translation>
    </message>
    <message>
        <source>file empty !
</source>
        <translation>파일이 비어 있습니다!
</translation>
    </message>
    <message>
        <source>malformed string</source>
        <translation>잘못된 문자열</translation>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation>닫는 따옴표 없음</translation>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation>내부 - unget 최소값을 벗어남</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>그룹</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>제목</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자 이름</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>암호</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>메모</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation>브라우저 통합</translation>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation>YubiKey[%1] 질의 응답 - 슬롯 %2 - %3</translation>
    </message>
    <message>
        <source>Press</source>
        <translation>누르기</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>수동적</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>압축 중 내부 zlib 오류 발생:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>장치에 기록하는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>장치를 여는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>장치에서 읽는 중 오류 발생:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>압축 푸는 중 내부 zlib 오류 발생:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>이 버전의 zlib에서 gzip 형식을 지원하지 않습니다.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>내부 zlib 오류: </translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>대소문자 구분</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>비우기</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation>찾기...</translation>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation>지정한 그룹에서만 찾기</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>이름이 &quot;%1&quot;인 공유 암호화 키가 이미 있습니다.
덮어쓰시겠습니까?</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>%1 - %2의 정보를 업데이트하시겠습니까?</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>활성 데이터베이스가 잠겨 있습니다!
선택한 데이터베이스의 잠금을 풀거나 잠금이 풀린 데이터베이스를 선택하십시오.</translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>KeePassX/HTTP 설정에서 %1 암호화-%2을(를) 삭제했습니다.</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>KeePassHttp 설정에서 공유 암호화 키를 찾을 수 없습니다.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>활성 데이터베이스에 KeePassHttp 설정 항목이 없습니다.</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>저장된 권한 삭제 중...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>%1 %2에서 권한을 삭제했습니다.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>활성 데이터베이스에 권한이 부여된 항목이 없습니다.</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC: 새 키 연결 요청</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>위에 있는 키의 연결 요청을 받았습니다.
해딩 키에서 KeePassXC 데이터베이스 접근을 허용하려면
식별할 수 있는 이름을 부여한 후 수락하십시오.</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC: 기존 키를 덮어쓰시겠습니까?</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC: 항목 업데이트</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC: 데이터베이스 잠김!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC: 데이터베이스에서 키 삭제됨</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC: 키를 찾을 수 없음</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC: 설정을 사용할 수 없음!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC: 권한 삭제됨</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC: 권한이 있는 항목을 찾을 수 없음!</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>프로그램 설정</translation>
    </message>
    <message>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>보안</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>설정 파일 %1에 접근할 수 없음</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>마지막 데이터베이스 기억</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>끝낼 때 자동 저장</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>항목을 변경할 때 자동 저장</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>클립보드에 복사할 때 최소화</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>항목을 만들 때 그룹 아이콘 사용</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>전역 자동 입력 단축키</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>언어</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>시스템 트레이 아이콘 표시</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>시스템 트레이로 최소화</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>시작할 때 이전 데이터베이스 불러오기</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>외부에서 데이터베이스를 수정했을 때 자동으로 새로 고침</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>프로그램을 끝내지 않고 시스템 트레이로 창 숨기기</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>프로그램 시작 시 창 최소화</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>기본 설정</translation>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation>마지막 키 파일과 보안 동글 기억</translation>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation>데이터가 변경되지 않았을 때 데이터베이스를 수정된 것으로 표시하지 않음(예: 그룹 확장)</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>자동 입력</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation>전역 자동 입력 창을 검사할 때 항목 제목과 URL 사용</translation>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation>자동 입력 시 항상 묻기</translation>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation>자동 입력 지연 시간</translation>
    </message>
    <message>
        <source> ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation>KeePassXC 단일 인스턴스만 사용</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>다음 시간 이후 클립보드 비우기</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>초</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>다음 시간 동안 활동이 없을 때 데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>기본값으로 암호를 평문으로 표시</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>창을 최소화할 때 데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>암호가 보일 때 반복하지 않음</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation>시간 제한</translation>
    </message>
    <message>
        <source>Convenience</source>
        <translation>편의성</translation>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation>세션이 잠겼을 때나 덮개를 닫았을 때 데이터베이스 잠금</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>개인 정보</translation>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation>웹 사이트 아이콘의 대체 아이콘으로 Google 사용</translation>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation>TOTP 설정</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>키:</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>사용자 정의 설정 사용</translation>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation>메모: 무엇을 하는 지 알고 있는 경우에만 이 설정을 변경하십시오.</translation>
    </message>
    <message>
        <source>Time step:</source>
        <translation>시간 단계:</translation>
    </message>
    <message>
        <source>8 digits</source>
        <translation>8자리</translation>
    </message>
    <message>
        <source>6 digits</source>
        <translation>6자리</translation>
    </message>
    <message>
        <source>Code size:</source>
        <translation>코드 크기:</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>초</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation>시간 제한된 암호</translation>
    </message>
    <message>
        <source>000000</source>
        <translation>000000</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Expires in</source>
        <translation>만료 시간:</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>초</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>데이터베이스 잠금 해제</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation>KeePassXC에 오신 것을 환영합니다</translation>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation>KeePassXC 데이터베이스에 암호를 안전하게 저장하십시오</translation>
    </message>
    <message>
        <source>Create new database</source>
        <translation>새 데이터베이스 만들기</translation>
    </message>
    <message>
        <source>Open existing database</source>
        <translation>기존 데이터베이스 열기</translation>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation>KeePass 1에서 가져오기</translation>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation>CSV에서 가져오기</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>최근 데이터베이스</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>사용자 정의 설정 파일 경로</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>데이터베이스 키 파일</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeePassXC - 크로스 플랫폼 암호 관리자</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>표준 입력에서 데이터베이스 암호 읽기</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>열 암호 데이터베이스 파일 이름(*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation>클립보드에 암호 복사</translation>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation>데이터베이스의 경로입니다.</translation>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation>데이터베이스 잠금을 해제할 GUI 프롬프트를 표시합니다.</translation>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation>클립보드에 복사할 항목 이름입니다.</translation>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation>데이터베이스의 내용을 추출하고 표시합니다.</translation>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation>표시할 데이터베이스 경로입니다.</translation>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation>실행할 명령 이름입니다.</translation>
    </message>
    <message>
        <source>List database entries.</source>
        <translation>데이터베이스 항목을 표시합니다.</translation>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation>표시할 그룹의 경로입니다. 기본값은 /입니다</translation>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation>항목과 그룹의 UUID를 표시합니다.</translation>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation>두 데이터베이스를 합칩니다.</translation>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation>합칠 대상 데이터베이스 경로입니다.</translation>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation>합칠 원본 데이터베이스 경로입니다.</translation>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation>두 데이터베이스에 같은 암호를 사용합니다.</translation>
    </message>
    <message>
        <source>Show a password.</source>
        <translation>암호를 표시합니다.</translation>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation>표시할 항목 이름입니다.</translation>
    </message>
</context>
</TS>